@@ -5,8 +5,10 @@ import (
 	"time"
 )
 
+var r *rand.Rand
+
 func init() {
-	rand.Seed(time.Now().UnixNano())
+	r = rand.New(rand.NewSource(time.Now().UnixNano()))
 }
 
 var letter = []rune("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789")
@@ -15,7 +17,7 @@ func RandomString(n int) string {
 	b := make([]rune, n)
 
 	for i := range b {
-		b[i] = letter[rand.Intn(len(letter))]
+		b[i] = letter[r.Intn(len(letter))]
 	}
 
 	return string(b)
